==> accounts_management-0.1.6.gem: app/controllers/accounts_management/accounts/client_accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Accounts::ClientAccountsController < AccountsManagementController
    # GET /accounts/client_accounts
    # GET /accounts/client_accounts.json
    def index
      @accounts_client_accounts = Accounts::ClientAccount.all
  
      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @accounts_client_accounts }
      end
    end
  
    # GET /accounts/client_accounts/1
    # GET /accounts/client_accounts/1.json
    def show
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
  
      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @accounts_client_account }
      end
    end
  
    # GET /accounts/client_accounts/new
    # GET /accounts/client_accounts/new.json
    def new
      @accounts_client_account = Accounts::ClientAccount.new
  
      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @accounts_client_account }
      end
    end
  
    # GET /accounts/client_accounts/1/edit
    def edit
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
    end
  
    # POST /accounts/client_accounts
    # POST /accounts/client_accounts.json
    def create
      @accounts_client_account = Accounts::ClientAccount.new(params[:accounts_client_account])
  
      respond_to do |format|
        if @accounts_client_account.save
          format.html { redirect_to @accounts_client_account, :notice => 'Client account was successfully created.' }
          format.json { render :json => @accounts_client_account, :status => :created, :location => @accounts_client_account }
        else
          format.html { render :action => "new" }
          format.json { render :json => @accounts_client_account.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # PUT /accounts/client_accounts/1
    # PUT /accounts/client_accounts/1.json
    def update
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
  
      respond_to do |format|
        if @accounts_client_account.update_attributes(params[:accounts_client_account])
          format.html { redirect_to @accounts_client_account, :notice => 'Client account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @accounts_client_account.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # DELETE /accounts/client_accounts/1
    # DELETE /accounts/client_accounts/1.json
    def destroy
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
      @accounts_client_account.destroy
  
      respond_to do |format|
        format.html { redirect_to accounts_client_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/accounts/client_accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Accounts::ClientAccountsController < AccountsManagementController
    # GET /accounts/client_accounts
    # GET /accounts/client_accounts.json
    def index
      @accounts_client_accounts = Accounts::ClientAccount.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @accounts_client_accounts }
      end
    end

    # GET /accounts/client_accounts/1
    # GET /accounts/client_accounts/1.json
    def show
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @accounts_client_account }
      end
    end

    # GET /accounts/client_accounts/new
    # GET /accounts/client_accounts/new.json
    def new
      @accounts_client_account = Accounts::ClientAccount.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @accounts_client_account }
      end
    end

    # GET /accounts/client_accounts/1/edit
    def edit
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
    end

    # POST /accounts/client_accounts
    # POST /accounts/client_accounts.json
    def create
      @accounts_client_account = Accounts::ClientAccount.new(params[:accounts_client_account])

      respond_to do |format|
        if @accounts_client_account.save
          format.html { redirect_to @accounts_client_account, notice: 'Client account was successfully created.' }
          format.json { render json: @accounts_client_account, status: :created, location: @accounts_client_account }
        else
          format.html { render action: "new" }
          format.json { render json: @accounts_client_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /accounts/client_accounts/1
    # PUT /accounts/client_accounts/1.json
    def update
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])

      respond_to do |format|
        if @accounts_client_account.update_attributes(params[:accounts_client_account])
          format.html { redirect_to @accounts_client_account, notice: 'Client account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @accounts_client_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /accounts/client_accounts/1
    # DELETE /accounts/client_accounts/1.json
    def destroy
      @accounts_client_account = Accounts::ClientAccount.find(params[:id])
      @accounts_client_account.destroy

      respond_to do |format|
        format.html { redirect_to accounts_client_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end
